@@ -2,10 +2,14 @@ from typing import Optional, Tuple
 
 import click
 
-from ..decorators import loses_interactivity, require_bins, require_login
-from ..helpers.ansible import run_ansible
-from ..helpers.global_options import GlobalOptions
-from ..helpers.options import ansible_options, resource_argument
+from sym.cli.actions.action_registry import ActionRegistry
+from sym.cli.data.ansible_options import AnsibleOptions
+from sym.cli.data.request_data import RequestData
+from sym.cli.decorators import command_require_bins, loses_interactivity, require_login
+from sym.cli.helpers.global_options import GlobalOptions
+from sym.cli.helpers.options import ansible_options as click_ansible_options
+from sym.cli.helpers.options import resource_argument
+
 from .sym import sym
 
 
@@ -15,11 +19,11 @@ from .sym import sym
 )
 @resource_argument
 @click.argument("command", nargs=-1)
-@ansible_options
+@click_ansible_options
 @click.make_pass_decorator(GlobalOptions)
-@loses_interactivity
-@require_bins("ansible", "aws", "session-manager-plugin")
+@command_require_bins("ansible", "aws", "session-manager-plugin")
 @require_login
+@loses_interactivity
 def ansible(
     options: GlobalOptions,
     resource: str,
@@ -39,13 +43,21 @@ def ansible(
     Example:
         `sym ansible RESOURCE all -m ping`
     """
-    client = options.create_saml_client(resource)
-    run_ansible(
-        client,
-        command,
-        ansible_aws_profile=ansible_aws_profile,
-        ansible_sym_resource=ansible_sym_resource,
+
+    ansible_options = AnsibleOptions(
+        command=command,
         control_master=control_master,
         send_command=send_command,
         forks=forks,
+        ansible_aws_profile=ansible_aws_profile,
+        ansible_sym_resource=ansible_sym_resource,
     )
+
+    request_data = RequestData(
+        action="ansible",
+        resource=resource,
+        global_options=options,
+        ansible_options=ansible_options,
+    )
+
+    ActionRegistry.execute(request_data)
