@@ -3,7 +3,7 @@ import subprocess
 import sys
 import tarfile
 from pathlib import Path
-from subprocess import CalledProcessError, TimeoutExpired
+from subprocess import CalledProcessError, CompletedProcess, TimeoutExpired
 from typing import Optional, Sequence
 from urllib.error import URLError
 from urllib.request import urlcleanup, urlretrieve
@@ -66,25 +66,31 @@ class SymUpdater:
     def is_brew(self):
         return Path("/usr/local/Cellar") in self.dir.parents
 
-    def _update_with_command(self, command: Sequence[str]) -> bool:
+    def _update_with_command(
+        self, command: Sequence[str], **kwargs
+    ) -> Optional[CompletedProcess]:
         if not has_command(command[0]):
-            return False
+            return None
         try:
-            subprocess.run(
+            return subprocess.run(
                 command,
                 timeout=INSTALL_TIMEOUT,
-                check=True,
-                capture_output=True,
+                **kwargs,
             )
-            return True
         except (CalledProcessError, TimeoutExpired):
-            return False
+            return None
 
     def update_pipx(self) -> bool:
-        return self._update_with_command(["pipx", "upgrade", "sym-cli", "--force"])
+        if (cp := self._update_with_command(["pipx", "upgrade", "sym-cli", "--force"])) :
+            return cp.returncode in {0, 1}
+        return False
 
     def update_brew(self) -> bool:
-        return self._update_with_command(["brew", "upgrade", "sym-cli"])
+        return bool(
+            self._update_with_command(
+                ["brew", "upgrade", "sym-cli"], check=True, capture_output=True
+            )
+        )
 
     def update_other(self) -> bool:
         if not self.url:
@@ -115,7 +121,7 @@ class SymUpdater:
             return self.update_brew()
         return self.update_other()
 
-    def update(self, exec=False):
+    def update(self, replace=False):
         self._log("Quickly checking for Sym CLI updates...", fg="white", nl=False)
         if not self.needs_update():
             self._log("no updates found, carry on!", fg="white")
@@ -125,7 +131,7 @@ class SymUpdater:
         self._log("Updating...", nl=False)
         if self._update():
             self._log("finished!", fg="green")
-            if exec:
+            if replace:
                 reset_fds()
                 os.execvp(sys.argv[0], sys.argv)
         else:
@@ -135,7 +141,7 @@ class SymUpdater:
         try:
             if not self.should_check():
                 return
-            self.update(exec=True)
+            self.update(replace=True)
         except:
             return  # just to be safe
 
